@@ -14,7 +14,6 @@ OC.L10N.register(
     "Guest" : "Invitado",
     "Talk to %s" : "Hablar con %s",
     "Join call" : "Unirse a la llamada",
-    "{user} wants to talk with you" : "{user} quiere hablar contigo",
     "A group call has started in {call}" : "Una llamada en grupo ha iniciado en {call}",
     "Open settings" : "Abrir configuraciones",
     "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
@@ -36,21 +35,19 @@ OC.L10N.register(
     "Pending" : "Pendiente",
     "Error" : "Error",
     "Blocked" : "Bloqueado",
+    "Shared secret" : "Secreto compartido",
     "Validate SSL certificate" : "Validar certificado SSL",
     "Saved" : "Guardado",
-    "Shared secret" : "Secreto compartido",
     "STUN servers" : "Servidores STUN",
     "A STUN server is used to determine the public IP address of participants behind a router." : "Un servidor STUN se está usando para determinar la IP pública de los participantes que estén detrás de un ruteador. ",
     "TURN server protocols" : "Protocolos del servidor TURN",
-    "UDP and TCP" : "UDP y TCP",
-    "UDP only" : "UDP únicamente",
-    "TCP only" : "TCP únicamente",
     "Copy link" : "Copiar liga",
     "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
     "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otras personas en la pestaña de participante del menú lateral",
     "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
     "Show your screen" : "Mostrar tu pantalla",
     "Stop screensharing" : "Dejar de compartir la pantalla",
+    "Settings" : "Configuraciones ",
     "Dismiss" : "Descartar",
     "Mute audio" : "Silenciar audio",
     "Disable video" : "Deshabilitar video",
@@ -62,16 +59,25 @@ OC.L10N.register(
     "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor usa un navegador diferente como Firefox o Chrome para compartir tu pantalla.",
     "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
+    "Back" : "Atrás",
     "You" : "Tú",
     "Show screen" : "Mostrar pantalla",
     "Favorite" : "Hacer favorito",
+    "Password protection" : "Protección con contraseña",
+    "Enter a password" : "Ingresa una contraseña",
+    "Save" : "Guardar",
+    "Edit" : "Editar",
+    "Password" : "Contraseña",
+    "API token" : "Ficha del API",
+    "Login" : "Iniciar sesión",
+    "Nickname" : "Apodo",
+    "Client ID" : "ID del cliente",
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a tus favoritos",
     "Loading" : "Cargando",
     "Groups" : "Grupos",
     "Circles" : "Círculos",
     "Password protect" : "Proteger con contraseña",
-    "Back" : "Atrás",
     "Close" : "Cerrar",
     "Reply" : "Responder",
     "Today" : "Hoy",
@@ -84,54 +90,28 @@ OC.L10N.register(
     "Add users or groups" : "Agregar usuarios o grupos",
     "Participants" : "Participantes",
     "Chat" : "Chat",
-    "Settings" : "Configuraciones ",
-    "Edit" : "Editar",
-    "Share link" : "Compartir liga",
-    "Password protection" : "Protección con contraseña",
-    "Enter a password" : "Ingresa una contraseña",
+    "Keyboard shortcuts" : "Atajos del teclado",
+    "Search" : "Buscar",
     "Grid view" : "Vista de cuadrícula",
+    "Send" : "Enviar",
+    "Default" : "Predeterminado",
     "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
     "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
     "WebRTC is not supported in your browser" : "WebRTC no está soportado en tu navegador",
     "Please use a different browser like Firefox or Chrome" : "Por favor usa un navegador diferente como Firefox o Chrome",
     "Error while accessing microphone & camera" : "Se pressentó un error al acceder al micrófono & cámara",
     "The password is wrong. Try again." : "La contraseña está equivoada. Por favor vuelve a intentarlo. ",
-    "Password" : "Contraseña",
     "TURN server" : "Servidor TURN",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
     "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Un servidor externo de señalización puede ser, opcionalmente, utilizado para instalaciones más grandes. Déjalo vacío para usar el sevidor de señalización interno. ",
     "Android app" : "Aplicación android",
     "iOS app" : "Aplicación iOS",
-    "Copy" : "Copiar",
-    "Copied!" : "¡Copiado!",
-    "Not supported!" : "¡No soportado!",
-    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
-    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
-    "Please enter the password for this call" : "Por favor ingresa la contraseña para esta llamada",
-    "Password required" : "Contraseña requerida",
-    "Cancel" : "Cancelar",
-    "Submit" : "Enviar",
-    "Guests" : "Invitados",
-    "Change password" : "Cambiar contraseña",
-    "Set password" : "Establecer contraseña",
-    "Rename" : "Renombrar",
-    "No messages yet, start the conversation!" : "Aún no hay mensajes. ¡!Inicia la conversación!",
-    "Send" : "Enviar",
-    "Share" : "Compartir",
-    "[Unknown user name]" : "[Nombre de usuario desconocido]",
-    "Error occurred while sending message" : "Se presentó un error al enviar el mensaje",
-    "Error while sharing" : "Se presentó un error al compartir",
-    "No other people in this call" : "No hay más personas en esta llamada",
-    "Waiting for {participantName} to join the call …" : "Esperando a que {participantName} se una a la llamada…",
-    "WebRTC is not supported in your browser :-/" : "WebRTC no se encuentra soportado en tu navegador :-/",
-    "Waiting for camera and microphone permissions" : "Aguardando los permisos para la cámara y micrófono",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "Por favor da acceso a tu navegador para usar tu camara y micrófono poder usar esta aplicación. ",
-    "Share screen" : "Compartir la pantalla",
-    "Screensharing is not supported by your browser." : "Compartir pantalla no está soportado por tu navegador. ",
-    "Favorited" : "Marcado como favorito",
-    "Your screen" : "Tu pantalla",
-    "{participantName}'s screen" : "Pantalla de {participantName}",
-    "Guest's screen" : "Pantalla del invitado",
-    "Contacts" : "Contactos"
+    "{user} wants to talk with you" : "{user} quiere hablar contigo",
+    "UDP and TCP" : "UDP y TCP",
+    "UDP only" : "UDP únicamente",
+    "TCP only" : "TCP únicamente",
+    "Share link" : "Compartir liga",
+    "Remove" : "Eliminar",
+    "Enabled" : "Habilitado"
 },
 "nplurals=2; plural=(n != 1);");
