@@ -41,9 +41,6 @@ OC.L10N.register(
     "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} го преименува разговорот од \"%1$s\" во \"%2$s\"",
     "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Го преименувавте разговорот од \"%1$s\" to \"%2$s\"",
     "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Администраторот го преименуваше разговорот од \"%1$s\" во \"%2$s\"",
-    "{actor} set the description to \"%1$s\"" : "{actor} го постави описот во \"%1$s\"",
-    "You set the description to \"%1$s\"" : "Го променивте описот во \"%1$s\"",
-    "An administrator set the description to \"%1$s\"" : "Администраторот го постави описот во \"%1$s\"",
     "{actor} removed the description" : "{actor} го избриша описот",
     "You removed the description" : "Го избришавте описот",
     "An administrator removed the description" : "Администраторот го избриша описот",
@@ -102,12 +99,6 @@ OC.L10N.register(
     "An administrator demoted {user} from moderator" : "Администраторот го деградираше {user} од модератор",
     "{actor} shared a file which is no longer available" : "{actor} сподели датотека која не е достапна повеќе",
     "You shared a file which is no longer available" : "Споделивте датотека која не е достапна повеќе",
-    "{actor} set up Matterbridge to synchronize this conversation with other chats." : "{actor} постави мост за да го синхронизира овој разговор со друг разговор на друга платформа.",
-    "You set up Matterbridge to synchronize this conversation with other chats." : "Поставивте мост за да го синхронизира овој разговор со друг разговор на друга платформа.",
-    "{actor} updated the Matterbridge configuration." : "{actor} ја ажурираше конфигурацијата на мостот.",
-    "You updated the Matterbridge configuration." : "Ја ажуриравте конфигурацијата на мостот.",
-    "{actor} removed the Matterbridge configuration." : "{actor} ја избриша конфигурацијата на мостот.",
-    "You removed the Matterbridge configuration." : "Ја избришавте конфигурацијата на мостот.",
     "%s (guest)" : "%s (гостин)",
     "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Повик со %n гостин (Времетраење {duration})","Повик со %n гости (Времетраење {duration})"],
     "Call with {user1} and {user2} (Duration {duration})" : "Повик со {user1} и {user2} (Времетраење {duration})",
@@ -520,8 +511,6 @@ OC.L10N.register(
     "Share this link to invite others!" : "Споделете ја оваа врска за да поканите други учесници!",
     "Conversation link copied to clipboard." : "Линк до разговорот е копиран во клипборд.",
     "The link could not be copied." : "Линкот неможе да се копира.",
-    "Share whole screen" : "Сподели го целиот екран",
-    "Share a single window" : "Сподели единечен прозор",
     "Show your screen" : "Прикажи го вашиот екран",
     "Stop screensharing" : "Запри споделување на екран",
     "Settings" : "Параметри",
@@ -638,7 +627,6 @@ OC.L10N.register(
     "No camera available" : "Нема камера",
     "Select camera" : "Избери камера",
     "Reply" : "Одговор",
-    "Remove" : "Отстрани",
     "[Unknown username]" : "[Непознато корисничко име]",
     "Scroll to bottom" : "Скролај до долу",
     "Today" : "Денес",
@@ -685,7 +673,6 @@ OC.L10N.register(
     "Shortcuts while in a call" : "Кратенки за време на повик",
     "Video on and off" : "Вклучување и исклучување на видеото",
     "Microphone on and off" : "Вклучување и исклучување на микрофонот",
-    "Choose in which folder attachments should be saved." : "Изберете во која папка ќе се зачувуваат примероците.",
     "Select location for attachments" : "Избери локација за прилози",
     "Error while setting attachment folder" : "Грешка при поставување на папка за прилози",
     "Start call" : "Повик",
@@ -744,6 +731,8 @@ OC.L10N.register(
     "UDP and TCP" : "UDP и TCP",
     "UDP only" : "Само UDP",
     "TCP only" : "Само TCP",
+    "Share whole screen" : "Сподели го целиот екран",
+    "Share a single window" : "Сподели единечен прозор",
     "Mute audio (m)" : "Занеми (Mute) го аудиото (m)",
     "Unmute audio (m)" : "Одзанеми (Unmute) го аудиото (m)",
     "Disable video (v)" : "Оневозможи видео (v)",
@@ -763,9 +752,20 @@ OC.L10N.register(
     "Select a conversation to add to the project" : "Избери разговор за да го додадете во проект",
     "Error while uploading file" : "Грешка при прикачување на датотека",
     "New in Talk 10" : "Ново во Talk 10",
+    "{actor} set up Matterbridge to synchronize this conversation with other chats." : "{actor} постави мост за да го синхронизира овој разговор со друг разговор на друга платформа.",
+    "You set up Matterbridge to synchronize this conversation with other chats." : "Поставивте мост за да го синхронизира овој разговор со друг разговор на друга платформа.",
+    "{actor} updated the Matterbridge configuration." : "{actor} ја ажурираше конфигурацијата на мостот.",
+    "You updated the Matterbridge configuration." : "Ја ажуриравте конфигурацијата на мостот.",
+    "{actor} removed the Matterbridge configuration." : "{actor} ја избриша конфигурацијата на мостот.",
+    "You removed the Matterbridge configuration." : "Ја избришавте конфигурацијата на мостот.",
     "E-mail of the user" : "Е-пошта на корисник",
+    "Remove" : "Отстрани",
     "Bridge with other services" : "Мост со други сервери",
     "Enabled" : "Овозможен",
-    "User name or e-mail address" : "Корисничко име или е-пошта адреса"
+    "User name or e-mail address" : "Корисничко име или е-пошта адреса",
+    "Choose in which folder attachments should be saved." : "Изберете во која папка ќе се зачувуваат примероците.",
+    "{actor} set the description to \"%1$s\"" : "{actor} го постави описот во \"%1$s\"",
+    "You set the description to \"%1$s\"" : "Го променивте описот во \"%1$s\"",
+    "An administrator set the description to \"%1$s\"" : "Администраторот го постави описот во \"%1$s\""
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
