@@ -31,19 +31,17 @@ OC.L10N.register(
     "- You can now search for chats and messages in the unified search in the top bar" : "- Nu kan du söka efter chattar och meddelanden gemensamt från sökrutan i menyn",
     "- Spice up your messages with emojis from the emoji picker" : "- Snygga till dina meddelanden med emojis",
     "- You can now change your camera and microphone while being in a call" : "- Nu går det att ändra kameran och mikrofonen medans du sitter i ett samtal",
+    "- Raise your hand in a call with the R key" : "- Lyft handen i ett samtal med R-tangenten",
     "There are currently no commands available." : "Det finns för närvarande inga kommandon tillgängliga.",
     "The command does not exist" : "Kommandot finns inte",
     "An error occurred while running the command. Please ask an administrator to check the logs." : "Ett fel inträffade under körning av kommandot. Be en administratör att kontrollera loggarna.",
-    "Talk updates ✅" : "Talk uppdateringar ✅",
+    "Talk updates ✅" : "Talk-uppdateringar ✅",
     "{actor} created the conversation" : "{actor} skapade konversationen",
     "You created the conversation" : "Du skapade konversationen",
     "An administrator created the conversation" : "En administratör skapade konversationen",
     "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} bytte namn på konversationen från \"%1$s\" till \"%2$s\"",
     "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Du bytte namn på konversationen från \"%1$s\" till \"%2$s\"",
     "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "En administratör döpte om konversationen från \"%1$s\" till \"%2$s\"",
-    "{actor} set the description to \"%1$s\"" : "{actor} ändrade beskrivningen till \"%1$s\"",
-    "You set the description to \"%1$s\"" : "Du ändrade beskrivningen till \"%1$s\"",
-    "An administrator set the description to \"%1$s\"" : "En administratör ändrade beskrivningen till \"%1$s\"",
     "{actor} removed the description" : "{actor} tog bort beskrivningen",
     "You removed the description" : "Du tog bort beskrivningen",
     "An administrator removed the description" : "En administratör tog bort beskrivningen",
@@ -59,6 +57,12 @@ OC.L10N.register(
     "{actor} locked the conversation" : "{actor} låste konversationen",
     "You locked the conversation" : "Du låste konversationen",
     "An administrator locked the conversation" : "En administratör låste konversationen",
+    "{actor} opened the conversation to registered users" : "{actor} öppnade konversationen för registrerade användare",
+    "You opened the conversation to registered users" : "Du öppnade konversationen för registrerade användare",
+    "An administrator opened the conversation to registered users" : "En administratör öppnade konversationen för registrerade användare",
+    "{actor} opened the conversation to registered and guest app users" : "{actor} öppnade konversationen för registrerade och gästappanvändare",
+    "You opened the conversation to registered and guest app users" : "Du öppnade konversationen för registrerade och gästappanvändare",
+    "An administrator opened the conversation to registered and guest app users" : "En administratör öppnade konversationen för registrerade och gästappsanvändare",
     "The conversation is now open to everyone" : "Konversationen är nu öppen för alla",
     "{actor} opened the conversation to everyone" : "{actor} öppnade konversationen för alla",
     "You opened the conversation to everyone" : "Du öppnade konversationen för alla",
@@ -102,8 +106,6 @@ OC.L10N.register(
     "An administrator demoted {user} from moderator" : "En administratör tog bort {user} som moderator",
     "{actor} shared a file which is no longer available" : "{actor} delade en fil som inte längre är tillgänglig",
     "You shared a file which is no longer available" : "Du delade en fil som inte längre är tillgänglig",
-    "{actor} set up Matterbridge to synchronize this conversation with other chats." : "{actor} aktiverade Matterbridge för att synkronisera denna konversation med andra chattar",
-    "You set up Matterbridge to synchronize this conversation with other chats." : "Du aktiverade Matterbridge för att synkronisera denna konversation med andra chattar",
     "%s (guest)" : "%s (gäst)",
     "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Samtal med %n gäst (Varaktighet {duration})","Samtal med %n gäster (Varaktighet {duration})"],
     "Call with {user1} and {user2} (Duration {duration})" : "Samtal med {user1} och {user2} (Varade {duration})",
@@ -112,7 +114,7 @@ OC.L10N.register(
     "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Samtal med {user1}, {user2}, {user3}, {user4} och {user5} (Varade {duration})",
     "Talk to %s" : "Prata med %s",
     "File is not shared, or shared but not with the user" : "Filen delas inte eller delas men inte med användaren",
-    "Talk mentions" : "Omnämningar",
+    "Talk mentions" : "Talk-omnämnanden",
     "Write to conversation" : "Skriv till konversation",
     "Writes event information into a conversation of your choice" : "Skriver händelseinformation till en konversation du väljer",
     "%s invited you to a conversation." : "%s bjöd in dig till en konversation.",
@@ -484,8 +486,6 @@ OC.L10N.register(
     "Share this link to invite others!" : "Dela denna länk för att bjuda in andra!",
     "Conversation link copied to clipboard." : "Konversationslänk kopierad till urklipp.",
     "The link could not be copied." : "Länken kunde inte kopieras.",
-    "Share whole screen" : "Dela hela skärmen",
-    "Share a single window" : "Dela ett fönster",
     "Show your screen" : "Visa din skärm",
     "Stop screensharing" : "Stoppa skärmdelning",
     "Settings" : "Inställningar",
@@ -525,6 +525,7 @@ OC.L10N.register(
     "Password protection" : "Lösenordsskydd",
     "Enter a password" : "Ange ett lösenord",
     "Copy conversation link" : "Kopiera konversationslänk",
+    "Open conversation to registered users" : "Öppna konversation för registrerade användare",
     "Enable lobby" : "Aktivera lobbyn",
     "Start time (optional)" : "Starttid (valfritt)",
     "Save" : "Spara",
@@ -566,7 +567,6 @@ OC.L10N.register(
     "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Du väntar för närvarande i lobbyn. Detta möte är planerat till {startTime}",
     "Camera" : "Kamera",
     "Reply" : "Svara",
-    "Remove" : "Ta bort",
     "[Unknown username]" : "[Okänt användarnamn]",
     "Today" : "Idag",
     "Yesterday" : "Igår",
@@ -611,6 +611,7 @@ OC.L10N.register(
     "Rename conversation" : "Byt namn på konversation",
     "Grid view" : "Rutnätsvy",
     "Send" : "Skicka",
+    "No unread mentions" : "Inga olästa omnämnanden",
     "Say hi to your friends and colleagues!" : "Säg hej till dina vänner och kollegor!",
     "Start a conversation" : "Starta en konversation",
     "Message without mention" : "Meddelande utan omnämnande",
@@ -662,6 +663,8 @@ OC.L10N.register(
     "UDP and TCP" : "UDP och TCP",
     "UDP only" : "endast UDP",
     "TCP only" : "endast TCP",
+    "Share whole screen" : "Dela hela skärmen",
+    "Share a single window" : "Dela ett fönster",
     "Mute audio (m)" : "Ljud av (m)",
     "Unmute audio (m)" : "Ljud på (m)",
     "Disable video (v)" : "Inaktivera video (v)",
@@ -683,6 +686,12 @@ OC.L10N.register(
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome or Apple Safari." : "Webbläsaren du använder stöds inte av Nextcloud Talk. Använd den senaste versionen av Mozilla Firefox, Microsoft Edge, Google Chrome eller Apple Safari.",
     "Error while uploading file" : "Fel vid uppladdning av fil",
     "New in Talk 10" : "Nytt i Talk 10",
-    "Enabled" : "Aktiverad"
+    "{actor} set up Matterbridge to synchronize this conversation with other chats." : "{actor} aktiverade Matterbridge för att synkronisera denna konversation med andra chattar",
+    "You set up Matterbridge to synchronize this conversation with other chats." : "Du aktiverade Matterbridge för att synkronisera denna konversation med andra chattar",
+    "Remove" : "Ta bort",
+    "Enabled" : "Aktiverad",
+    "{actor} set the description to \"%1$s\"" : "{actor} ändrade beskrivningen till \"%1$s\"",
+    "You set the description to \"%1$s\"" : "Du ändrade beskrivningen till \"%1$s\"",
+    "An administrator set the description to \"%1$s\"" : "En administratör ändrade beskrivningen till \"%1$s\""
 },
 "nplurals=2; plural=(n != 1);");
