@@ -89,7 +89,7 @@ class SystemMessage {
 
 		$message = $data['message'];
 		$parameters = $data['parameters'];
-		$parsedParameters = ['actor' => $this->getActor($comment)];
+		$parsedParameters = ['actor' => $this->getActorFromComment($comment)];
 
 		$participant = $chatMessage->getParticipant();
 		if (!$participant->isGuest()) {
@@ -120,6 +120,20 @@ class SystemMessage {
 			} elseif ($cliIsActor) {
 				$parsedMessage = $this->l->t('An administrator renamed the conversation from "%1$s" to "%2$s"', [$parameters['oldName'], $parameters['newName']]);
 			}
+		} elseif ($message === 'description_set') {
+			$parsedMessage = $this->l->t('{actor} set the description to "%1$s"', [$parameters['newDescription']]);
+			if ($currentUserIsActor) {
+				$parsedMessage = $this->l->t('You set the description to "%1$s"', [$parameters['newDescription']]);
+			} elseif ($cliIsActor) {
+				$parsedMessage = $this->l->t('An administrator set the description to "%1$s"', [$parameters['newDescription']]);
+			}
+		} elseif ($message === 'description_removed') {
+			$parsedMessage = $this->l->t('{actor} removed the description');
+			if ($currentUserIsActor) {
+				$parsedMessage = $this->l->t('You removed the description');
+			} elseif ($cliIsActor) {
+				$parsedMessage = $this->l->t('An administrator removed the description');
+			}
 		} elseif ($message === 'call_started') {
 			$parsedMessage = $this->l->t('{actor} started a call');
 			if ($currentUserIsActor) {
@@ -151,6 +165,27 @@ class SystemMessage {
 			} elseif ($cliIsActor) {
 				$parsedMessage = $this->l->t('An administrator locked the conversation');
 			}
+		} elseif ($message === 'listable_none') {
+			$parsedMessage = $this->l->t('{actor} limited the conversation to the current participants');
+			if ($currentUserIsActor) {
+				$parsedMessage = $this->l->t('You limited the conversation to the current participants');
+			} elseif ($cliIsActor) {
+				$parsedMessage = $this->l->t('An administrator limited the conversation to the current participants');
+			}
+		} elseif ($message === 'listable_users') {
+			$parsedMessage = $this->l->t('{actor} opened the conversation to registered users');
+			if ($currentUserIsActor) {
+				$parsedMessage = $this->l->t('You opened the conversation to registered users');
+			} elseif ($cliIsActor) {
+				$parsedMessage = $this->l->t('An administrator opened the conversation to registered users');
+			}
+		} elseif ($message === 'listable_all') {
+			$parsedMessage = $this->l->t('{actor} opened the conversation to registered and guest app users');
+			if ($currentUserIsActor) {
+				$parsedMessage = $this->l->t('You opened the conversation to registered and guest app users');
+			} elseif ($cliIsActor) {
+				$parsedMessage = $this->l->t('An administrator opened the conversation to registered and guest app users');
+			}
 		} elseif ($message === 'lobby_timer_reached') {
 			$parsedMessage = $this->l->t('The conversation is now open to everyone');
 		} elseif ($message === 'lobby_none') {
@@ -294,6 +329,10 @@ class SystemMessage {
 					$parsedMessage = $this->l->t('You shared a file which is no longer available');
 				}
 			}
+		} elseif ($message === 'object_shared') {
+			$parsedParameters['object'] = $parameters['metaData'];
+			$parsedMessage = '{object}';
+			$chatMessage->setMessageType('comment');
 		} elseif ($message === 'matterbridge_config_added') {
 			$parsedMessage = $this->l->t('{actor} set up Matterbridge to synchronize this conversation with other chats.');
 			if ($currentUserIsActor) {
@@ -309,6 +348,67 @@ class SystemMessage {
 			if ($currentUserIsActor) {
 				$parsedMessage = $this->l->t('You removed the Matterbridge configuration.');
 			}
+		} elseif ($message === 'matterbridge_config_enabled') {
+			$parsedMessage = $this->l->t('{actor} started Matterbridge.');
+			if ($currentUserIsActor) {
+				$parsedMessage = $this->l->t('You started Matterbridge.');
+			}
+		} elseif ($message === 'matterbridge_config_disabled') {
+			$parsedMessage = $this->l->t('{actor} stopped Matterbridge.');
+			if ($currentUserIsActor) {
+				$parsedMessage = $this->l->t('You stopped Matterbridge.');
+			}
+		} elseif ($message === 'message_deleted') {
+			$parsedMessage = $this->l->t('{actor} deleted a message');
+			if ($currentUserIsActor) {
+				$parsedMessage = $this->l->t('You deleted a message');
+			}
+		} else {
+			throw new \OutOfBoundsException('Unknown subject');
+		}
+
+		$chatMessage->setMessage($parsedMessage, $parsedParameters, $message);
+	}
+
+	/**
+	 * @param Message $chatMessage
+	 * @throws \OutOfBoundsException
+	 */
+	public function parseDeletedMessage(Message $chatMessage): void {
+		$this->l = $chatMessage->getL10n();
+		$data = json_decode($chatMessage->getMessage(), true);
+		if (!\is_array($data)) {
+			throw new \OutOfBoundsException('Invalid message');
+		}
+
+		$parsedParameters = ['actor' => $this->getActor($data['deleted_by_type'], $data['deleted_by_id'])];
+
+		$participant = $chatMessage->getParticipant();
+		$currentActorId = $participant->getAttendee()->getActorId();
+
+		$authorIsActor = $data['deleted_by_type'] === $chatMessage->getComment()->getActorType()
+			&& $data['deleted_by_id'] === $chatMessage->getComment()->getActorId();
+
+		if (!$participant->isGuest()) {
+			$currentUserIsActor = $parsedParameters['actor']['type'] === 'user' &&
+				$participant->getAttendee()->getActorType() === Attendee::ACTOR_USERS &&
+				$currentActorId === $parsedParameters['actor']['id'];
+		} else {
+			$currentUserIsActor = $parsedParameters['actor']['type'] === 'guest' &&
+				$participant->getAttendee()->getActorType() === 'guest' &&
+				$currentActorId === $parsedParameters['actor']['id'];
+		}
+
+		if ($chatMessage->getMessageType() === 'comment_deleted') {
+			$message = 'message_deleted';
+			$parsedMessage = $this->l->t('Message deleted by author');
+
+			if (!$authorIsActor) {
+				$parsedMessage = $this->l->t('Message deleted by {actor}');
+			}
+			if ($currentUserIsActor) {
+				$parsedMessage = $this->l->t('Message deleted by you');
+			}
 		} else {
 			throw new \OutOfBoundsException('Unknown subject');
 		}
@@ -328,6 +428,7 @@ class SystemMessage {
 		$share = $this->shareProvider->getShareById($shareId);
 		$node = $share->getNode();
 		$name = $node->getName();
+		$size = $node->getSize();
 		$path = $name;
 
 		if (!$participant->isGuest()) {
@@ -354,6 +455,7 @@ class SystemMessage {
 					$fullPath = $userNode->getPath();
 					$pathSegments = explode('/', $fullPath, 4);
 					$name = $userNode->getName();
+					$size = $userNode->getSize();
 					$path = $pathSegments[3] ?? $path;
 				}
 			} else {
@@ -375,6 +477,7 @@ class SystemMessage {
 			'type' => 'file',
 			'id' => (string) $node->getId(),
 			'name' => $name,
+			'size' => $size,
 			'path' => $path,
 			'link' => $url,
 			'mimetype' => $node->getMimeType(),
@@ -382,12 +485,16 @@ class SystemMessage {
 		];
 	}
 
-	protected function getActor(IComment $comment): array {
-		if ($comment->getActorType() === Attendee::ACTOR_GUESTS) {
-			return $this->getGuest($comment->getActorId());
+	protected function getActorFromComment(IComment $comment): array {
+		return $this->getActor($comment->getActorType(), $comment->getActorId());
+	}
+
+	protected function getActor(string $actorType, string $actorId): array {
+		if ($actorType === Attendee::ACTOR_GUESTS) {
+			return $this->getGuest($actorId);
 		}
 
-		return $this->getUser($comment->getActorId());
+		return $this->getUser($actorId);
 	}
 
 	protected function getUser(string $uid): array {
