@@ -105,6 +105,20 @@ trait TRoomCommand {
 		return (($name !== '') && !isset($name[255]));
 	}
 
+	/**
+	 * @param Room   $room
+	 * @param string $description
+	 *
+	 * @throws InvalidArgumentException
+	 */
+	protected function setRoomDescription(Room $room, string $description): void {
+		try {
+			$room->setDescription($description);
+		} catch (\LengthException $e) {
+			throw new InvalidArgumentException('Invalid room description.');
+		}
+	}
+
 	/**
 	 * @param Room $room
 	 * @param bool $public
@@ -137,6 +151,22 @@ trait TRoomCommand {
 		}
 	}
 
+	/**
+	 * @param Room $room
+	 * @param int $listable
+	 *
+	 * @throws InvalidArgumentException
+	 */
+	protected function setRoomListable(Room $room, int $listable): void {
+		if ($room->getListable() === $listable) {
+			return;
+		}
+
+		if (!$room->setListable($listable)) {
+			throw new InvalidArgumentException('Unable to change room state.');
+		}
+	}
+
 	/**
 	 * @param Room   $room
 	 * @param string $password
