@@ -159,7 +159,7 @@ class BackendNotifier {
 				// TODO(fancycode): We should try to get rid of 'alluserids' and
 				// find a better way to notify existing users to update the room.
 				'alluserids' => $this->participantService->getParticipantUserIds($room),
-				'properties' => $room->getPropertiesForSignaling(''),
+				'properties' => $room->getPropertiesForSignaling('', false),
 			],
 		]);
 	}
@@ -180,7 +180,7 @@ class BackendNotifier {
 				// TODO(fancycode): We should try to get rid of 'alluserids' and
 				// find a better way to notify existing users to update the room.
 				'alluserids' => $this->participantService->getParticipantUserIds($room),
-				'properties' => $room->getPropertiesForSignaling(''),
+				'properties' => $room->getPropertiesForSignaling('', false),
 			],
 		]);
 	}
@@ -201,7 +201,7 @@ class BackendNotifier {
 				// TODO(fancycode): We should try to get rid of 'alluserids' and
 				// find a better way to notify existing users to update the room.
 				'alluserids' => $this->participantService->getParticipantUserIds($room),
-				'properties' => $room->getPropertiesForSignaling(''),
+				'properties' => $room->getPropertiesForSignaling('', false),
 			],
 		]);
 	}
@@ -334,6 +334,7 @@ class BackendNotifier {
 				$data['inCall'] = $session->getInCall();
 				$data['lastPing'] = $session->getLastPing();
 				$data['sessionId'] = $session->getSessionId();
+				$data['nextcloudSessionId'] = $session->getSessionId();
 
 				if ($session->getInCall() !== Participant::FLAG_DISCONNECTED) {
 					$users[] = $data;
